from django.apps import AppConfig
from django.db.models.signals import post_migrate


def create_properties(sender, **kwargs):
    from .models import Property

    Property.objects.get_or_create(
        name="Capacitance",
        defaults={
            "filterable": True,
            "type": Property.Type.QUANTITY,
            "unit": "F",
            "scale": -12,
            "searchable": False,
        },
    )

    Property.objects.get_or_create(
        name="Footprint",
        defaults={
            "filterable": True,
            "type": Property.Type.TEXT,
            "unit": "",
            "scale": 0,
            "searchable": False,
        },
    )

    Property.objects.get_or_create(
        name="LCSC part number",
        defaults={
            "filterable": False,
            "type": Property.Type.TEXT,
            "unit": "",
            "scale": 0,
            "searchable": True,
        },
    )

    Property.objects.get_or_create(
        name="Inductance",
        defaults={
            "filterable": True,
            "type": Property.Type.QUANTITY,
            "unit": "H",
            "scale": -6,
            "searchable": False,
        },
    )

    Property.objects.get_or_create(
        name="Rated power",
        defaults={
            "filterable": True,
            "type": Property.Type.QUANTITY,
            "unit": "W",
            "scale": -4,
            "searchable": False,
        },
    )

    Property.objects.get_or_create(
        name="Rated voltage",
        defaults={
            "filterable": True,
            "type": Property.Type.QUANTITY,
            "unit": "V",
            "scale": -3,
            "searchable": False,
        },
    )

    Property.objects.get_or_create(
        name="Resistance",
        defaults={
            "filterable": True,
            "type": Property.Type.QUANTITY,
            "unit": "Ω",
            "scale": -3,
            "searchable": False,
        },
    )


class CoreConfig(AppConfig):
    default_auto_field = "django.db.models.BigAutoField"
    label = "lelcsc_core"
    name = "lelcsc.core"
    verbose_name = "core"

    def ready(self):
        post_migrate.connect(create_properties, sender=self)
