from django.conf import settings
from django.db import transaction
from mozilla_django_oidc.auth import (
    OIDCAuthenticationBackend as BaseOIDCAuthenticationBackend,
)

from .models import OIDCUser


def get_roles(claims):
    roles = claims

    roles_path = settings.OIDC_ROLES_CLAIM.split(".")
    for key in roles_path:
        roles = roles.get(key)
        if roles is None:
            return []

    return roles


class OIDCAuthenticationBackend(BaseOIDCAuthenticationBackend):
    @transaction.atomic
    def create_user(self, claims):
        is_superuser = settings.OIDC_SUPERUSER_ROLE in get_roles(claims)

        user = self.UserModel.objects.create_user(
            claims.get("preferred_username"),
            claims.get("email"),
            first_name=claims.get("given_name", ""),
            last_name=claims.get("family_name", ""),
            is_staff=is_superuser,
            is_superuser=is_superuser,
        )

        OIDCUser.objects.create(uuid=claims.get("sub"), user=user)

        return user

    def update_user(self, user, claims):
        user.username = claims.get("preferred_username")
        user.email = claims.get("email")
        user.first_name = claims.get("given_name", "")
        user.last_name = claims.get("family_name", "")
        user.is_superuser = user.is_staff = settings.OIDC_SUPERUSER_ROLE in get_roles(
            claims
        )
        user.save()

        return user

    def filter_users_by_claims(self, claims):
        uuid = claims.get("sub")
        if not uuid:
            return self.UserModel.objects.none()

        try:
            oidc_user = OIDCUser.objects.get(uuid=uuid)
            return [oidc_user.user]
        except OIDCUser.DoesNotExist:
            return self.UserModel.objects.none()
